@@ -1,9 +1,7 @@
-import imp
-from json import load
 import os
 
 from dotenv import load_dotenv
-from typing import Type, Union, Optional
+from typing import Union, Optional
 from disnake import (
     ButtonStyle,
     Embed,
@@ -116,16 +114,22 @@ class FindSnowflake:
             return channel
 
     @staticmethod
-    async def find_emoji(bot: Bot, query: str) -> Optional[TextChannel]:
+    async def find_emoji(bot: Bot, query: str) -> Optional[Emoji]:
         if not query.isalpha():  # id
-            _id = int(query)
-
-            emoji = bot.get_emoji(_id)
-            if isinstance(emoji, Emoji):
-                return emoji
-
+            try:
+                _id = int(query)
+            except ValueError:
+                try:
+                    _id = int(query.split(':')[-1][:-1])
+                    emoji = bot.get_emoji(_id)
+                    if isinstance(emoji, Emoji):
+                        return emoji
+                except ValueError:
+                    pass
+           
         emoji = utils.get(bot.emojis, name=query)
-        return emoji
+        if emoji:
+            return emoji
 
 class EmbedFactory:
     """Embed factory"""
